"use client";

import Image from "next/image";
import { useState } from "react";

import { AnimatePresence, motion } from "framer-motion";

import { Tabs, TabsList, TabsTrigger } from "@/components/ui/tabs";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { ProductFeaturesData } from "@/utils/get-fake-data";

interface ProductFeaturesClientProps {
	data: ProductFeaturesData;
	locale: Locale;
}

export function ProductFeaturesClient({
	data,
	locale,
}: ProductFeaturesClientProps) {
	const isRTL = locale === "ar";
	const [activeTab, setActiveTab] = useState(data.tabs[0].id);

	return (
		<section className="relative w-full overflow-hidden">
			{/* Background Image */}
			<div className="absolute inset-0">
				<Image
					src={data.backgroundImage}
					alt=""
					fill
					priority
					className="object-cover"
				/>
				<div className="absolute inset-0 bg-gradient-to-b from-[#2895C8]/40 via-[#2895C8]/30 to-[#2895C8]/40 shadow-sm blur-md backdrop-blur-lg" />
			</div>

			{/* Content */}
			<div className="relative z-10 flex flex-col items-center px-4 py-16">
				{/* Tabs */}
				<Tabs
					defaultValue={data.tabs[0].id}
					value={activeTab}
					onValueChange={setActiveTab}
					className="h-full w-full"
				>
					<TabsList className="mx-auto grid w-full max-w-2xl grid-cols-5 place-content-center justify-center justify-items-center rounded-2xl bg-custom-primary-accent p-2 py-7 backdrop-blur-sm">
						{data.tabs?.map((tab) => (
							<TabsTrigger
								key={tab.id}
								value={tab.id}
								className={cn(
									"relative text-sm font-medium text-white transition-all data-[state=active]:border-none data-[state=active]:bg-[#2895C8] data-[state=active]:text-white data-[state=active]:shadow-none md:text-base"
								)}
							>
								{tab.label?.[locale]}
								<span
									className={`absolute -bottom-2 left-1/2 h-2 w-2 -translate-x-1/2 rounded-full bg-white transition-opacity ${activeTab === tab.id ? "opacity-100" : "opacity-0"}`}
								/>
							</TabsTrigger>
						))}
					</TabsList>

					<div className="flex h-full min-h-[60vh] w-full items-center justify-center">
						{/* Content */}
						<div className="mt-16 max-w-4xl px-4">
							<AnimatePresence mode="wait">
								<motion.div
									key={activeTab}
									initial={{ opacity: 0, y: 20 }}
									animate={{ opacity: 1, y: 0 }}
									exit={{ opacity: 0, y: -20 }}
									transition={{ duration: 0.3 }}
									className={cn(
										"bg-gradient-to-r from-[#1E1E1E] to-[#1E1E1E] bg-clip-text text-center text-2xl leading-relaxed text-transparent bg-blend-luminosity md:text-4xl md:leading-[63.2px]",
										isRTL && "font-arabic"
									)}
									style={{ textShadow: "0px 4px 4px 0px #00000040" }}
								>
									{
										data.tabs.find((tab) => tab.id === activeTab)?.content[
										locale
										]
									}
								</motion.div>
							</AnimatePresence>
						</div>
					</div>
				</Tabs>
			</div>
		</section>
	);
}
